@@ -53,7 +53,6 @@ TT.plot(
 )   #
 
 # ::: Test all the texture triangles
-
 TT.plot( class.sys = "none" )           # no classification 
 TT.plot( class.sys = "HYPRES.TT" )      # HYPRES / European Soil Map 
 TT.plot( class.sys = "USDA.TT" )        # USDA 
@@ -67,21 +66,30 @@ TT.plot( class.sys = "CA.EN.TT" )       # Canada (en)
 TT.plot( class.sys = "AU2.TT" )         # Australian 
 TT.plot( class.sys = "ISSS.TT" )        # ISSS 
 TT.plot( class.sys = "ROM.TT" )         # Romanian 
-try( TT.plot( class.sys = "PL.TT" ) )   # Polish 
 TT.plot( class.sys = "DE.SEA74.TT" )    # German SEA 1974 
 TT.plot( class.sys = "DE.TGL85.TT" )    # German TGL 1985 
+TT.plot( class.sys = "USDA1911" )       # USDA 1911 (M. Whitney, 1911)
+TT.plot( class.sys = "BRASIL.TT" )      # Brasil (Lemos & Santos 1996)
+
+#   Triangles with special characters
+#   (may not work on all platforms + some accents can be missing)
+try( TT.plot( class.sys = "PL.TT" ) )   # Polish 
 
 
 # ::: Test all the languages:
+TT.plot( class.sys = "USDA.TT", lang = "en" )  # English, default 
+TT.plot( class.sys = "USDA.TT", lang = "fr" )  # French 
+TT.plot( class.sys = "USDA.TT", lang = "de" )  # German 
+TT.plot( class.sys = "USDA.TT", lang = "es" )  # Spanish 
+TT.plot( class.sys = "USDA.TT", lang = "it" )  # Italian 
+TT.plot( class.sys = "USDA.TT", lang = "nl" )  # Dutch 
+TT.plot( class.sys = "USDA.TT", lang = "fl" )  # Dutch (Belgium) / Flemish 
+TT.plot( class.sys = "USDA.TT", lang = "se" )  # Swedish 
+TT.plot( class.sys = "USDA.TT", lang = "ro" )  # Romanian 
 
-TT.plot( class.sys = "USDA.TT", lang = "en" )  #  English, default 
-TT.plot( class.sys = "USDA.TT", lang = "fr" )  #  French 
-TT.plot( class.sys = "USDA.TT", lang = "de" )  #  German 
-TT.plot( class.sys = "USDA.TT", lang = "es" )  #  Spanish 
-TT.plot( class.sys = "USDA.TT", lang = "it" )  #  Italian 
-TT.plot( class.sys = "USDA.TT", lang = "nl" )  #  Dutch 
-TT.plot( class.sys = "USDA.TT", lang = "fl" )  #  Dutch (Belgian) / Flemmish 
-TT.plot( class.sys = "USDA.TT", lang = "se" )  #  Swedish 
-TT.plot( class.sys = "USDA.TT", lang = "ro" )  #  Romanian 
-try( TT.plot( class.sys = "USDA.TT", lang = "pl" ) ) #  Polish 
-
+#   Languages with special characters
+#   (may not work on all platforms + some accents can be missing)
+try( TT.plot( class.sys = "USDA.TT", lang = "pl"  ) ) # Polish 
+try( TT.plot( class.sys = "USDA.TT", lang = "pt"  ) ) # Portuguese 
+try( TT.plot( class.sys = "USDA.TT", lang = "es2" ) ) # Spanish
+try( TT.plot( class.sys = "USDA.TT", lang = "ro2" ) ) # Romanian
